@@ -97,6 +97,10 @@
  * GtkSourceCompletionInfo for the main completion window.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcecompletion.h"
 #include "gtksourcecompletion-private.h"
 #include "gtksourcecompletionmodel.h"
@@ -109,7 +113,6 @@
 #include "gtksourceview.h"
 #include "gtksourceview-i18n.h"
 
-/* Signals */
 enum
 {
 	SHOW,
@@ -121,7 +124,7 @@ enum
 	MOVE_CURSOR,
 	MOVE_PAGE,
 
-	LAST_SIGNAL
+	N_SIGNALS
 };
 
 enum
@@ -200,7 +203,7 @@ struct _GtkSourceCompletionPrivate
 	guint show_icons : 1;
 };
 
-static guint signals[LAST_SIGNAL] = { 0 };
+static guint signals[N_SIGNALS];
 
 static void	gtk_source_completion_buildable_interface_init (GtkBuildableIface *iface);
 
@@ -1574,9 +1577,16 @@ style_context_changed (GtkStyleContext     *style_context,
 {
 	PangoFontDescription *font_desc = NULL;
 
-	gtk_style_context_get (style_context, GTK_STATE_FLAG_NORMAL,
+	gtk_style_context_save (style_context);
+	gtk_style_context_set_state (style_context, GTK_STATE_FLAG_NORMAL);
+
+	gtk_style_context_get (style_context,
+			       gtk_style_context_get_state (style_context),
 			       GTK_STYLE_PROPERTY_FONT, &font_desc,
 			       NULL);
+
+	gtk_style_context_restore (style_context);
+
 	/*
 	 * Work around issue where when a proposal provides "<b>markup</b>" and
 	 * the weight is set in the font description, the <b> markup will not
@@ -1591,9 +1601,11 @@ style_context_changed (GtkStyleContext     *style_context,
 	{
 		pango_font_description_unset_fields (font_desc, PANGO_FONT_MASK_WEIGHT);
 	}
+
 	g_object_set (completion->priv->cell_renderer_proposal,
 		      "font-desc", font_desc,
 		      NULL);
+
 	pango_font_description_free (font_desc);
 }
 
@@ -2016,7 +2028,7 @@ init_tree_view (GtkSourceCompletion *completion,
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell_renderer;
 	GtkStyleContext *style_context;
-	GdkRGBA background_color;
+	GdkRGBA* background_color = NULL;
 	GdkRGBA foreground_color;
 
 	completion->priv->tree_view_proposals = GTK_TREE_VIEW (gtk_builder_get_object (builder, "tree_view_proposals"));
@@ -2067,13 +2079,22 @@ init_tree_view (GtkSourceCompletion *completion,
 
 	style_context = gtk_widget_get_style_context (GTK_WIDGET (completion->priv->tree_view_proposals));
 
+	gtk_style_context_save (style_context);
+	gtk_style_context_set_state (style_context, GTK_STATE_FLAG_INSENSITIVE);
+
 	gtk_style_context_get (style_context,
-			       GTK_STATE_FLAG_INSENSITIVE,
+			       gtk_style_context_get_state (style_context),
 			       "background-color", &background_color,
 			       NULL);
 
+	gtk_style_context_get_color (style_context,
+				     gtk_style_context_get_state (style_context),
+				     &foreground_color);
+
+	gtk_style_context_restore (style_context);
+
 	g_object_set (cell_renderer,
-	              "cell-background-rgba", &background_color,
+	              "cell-background-rgba", background_color,
 	              NULL);
 
 	g_object_bind_property (completion, "show-icons",
@@ -2093,13 +2114,9 @@ init_tree_view (GtkSourceCompletion *completion,
 					     "foreground-set", GTK_SOURCE_COMPLETION_MODEL_COLUMN_IS_HEADER,
 					     NULL);
 
-	gtk_style_context_get_color (style_context,
-	                             GTK_STATE_FLAG_INSENSITIVE,
-	                             &foreground_color);
-
 	g_object_set (cell_renderer,
 	              "foreground-rgba", &foreground_color,
-	              "cell-background-rgba", &background_color,
+	              "cell-background-rgba", background_color,
 	              NULL);
 
 	/* Accelerators cell renderer */
@@ -2115,7 +2132,7 @@ init_tree_view (GtkSourceCompletion *completion,
 
 	g_object_set (cell_renderer,
 	              "foreground-rgba", &foreground_color,
-	              "cell-background-rgba", &background_color,
+	              "cell-background-rgba", background_color,
 		      NULL);
 
 	gtk_tree_view_column_set_cell_data_func (column,
@@ -2129,6 +2146,8 @@ init_tree_view (GtkSourceCompletion *completion,
 				 G_CALLBACK (accelerators_notify_cb),
 				 column,
 				 0);
+
+	gdk_rgba_free (background_color);
 }
 
 static void
@@ -2283,7 +2302,9 @@ gtk_source_completion_class_init (GtkSourceCompletionClass *klass)
 							      "View",
 							      "The GtkSourceView bound to the completion",
 							      GTK_SOURCE_TYPE_VIEW,
-							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+							      G_PARAM_READWRITE |
+							      G_PARAM_CONSTRUCT_ONLY |
+							      G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourceCompletion:remember-info-visibility:
@@ -2298,7 +2319,9 @@ gtk_source_completion_class_init (GtkSourceCompletionClass *klass)
 							       "Remember Info Visibility",
 							       "Remember the last info window visibility state",
 							       FALSE,
-							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+							       G_PARAM_READWRITE |
+							       G_PARAM_CONSTRUCT |
+							       G_PARAM_STATIC_STRINGS));
 	/**
 	 * GtkSourceCompletion:select-on-show:
 	 *
@@ -2311,7 +2334,9 @@ gtk_source_completion_class_init (GtkSourceCompletionClass *klass)
 							       "Select on Show",
 							       "Select first proposal when completion is shown",
 							       TRUE,
-							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+							       G_PARAM_READWRITE |
+							       G_PARAM_CONSTRUCT |
+							       G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourceCompletion:show-headers:
@@ -2325,7 +2350,9 @@ gtk_source_completion_class_init (GtkSourceCompletionClass *klass)
 							       "Show Headers",
 							       "Show provider headers when proposals from multiple providers are available",
 							       TRUE,
-							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+							       G_PARAM_READWRITE |
+							       G_PARAM_CONSTRUCT |
+							       G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourceCompletion:show-icons:
@@ -2339,7 +2366,9 @@ gtk_source_completion_class_init (GtkSourceCompletionClass *klass)
 							       "Show Icons",
 							       "Show provider and proposal icons in the completion popup",
 							       TRUE,
-							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+							       G_PARAM_READWRITE |
+							       G_PARAM_CONSTRUCT |
+							       G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourceCompletion:accelerators:
@@ -2356,7 +2385,9 @@ gtk_source_completion_class_init (GtkSourceCompletionClass *klass)
 	                                                    0,
 	                                                    10,
 	                                                    5,
-	                                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	                                                    G_PARAM_READWRITE |
+							    G_PARAM_CONSTRUCT |
+							    G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourceCompletion:auto-complete-delay:
@@ -2372,7 +2403,9 @@ gtk_source_completion_class_init (GtkSourceCompletionClass *klass)
 							    0,
 							    G_MAXUINT,
 							    250,
-							    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+							    G_PARAM_READWRITE |
+							    G_PARAM_CONSTRUCT |
+							    G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourceCompletion:provider-page-size:
@@ -2389,7 +2422,9 @@ gtk_source_completion_class_init (GtkSourceCompletionClass *klass)
 	                                                    1,
 	                                                    G_MAXUINT,
 	                                                    5,
-	                                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	                                                    G_PARAM_READWRITE |
+							    G_PARAM_CONSTRUCT |
+							    G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourceCompletion:proposal-page-size:
@@ -2410,7 +2445,9 @@ gtk_source_completion_class_init (GtkSourceCompletionClass *klass)
 	                                                    1,
 	                                                    G_MAXUINT,
 	                                                    5,
-	                                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+	                                                    G_PARAM_READWRITE |
+							    G_PARAM_CONSTRUCT |
+							    G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourceCompletion::show:
@@ -2721,7 +2758,7 @@ _gtk_source_completion_add_proposals (GtkSourceCompletion         *completion,
 /**
  * gtk_source_completion_show:
  * @completion: a #GtkSourceCompletion.
- * @providers: (element-type GtkSource.CompletionProvider) (allow-none):
+ * @providers: (element-type GtkSource.CompletionProvider) (nullable):
  * a list of #GtkSourceCompletionProvider, or %NULL.
  * @context: (transfer floating): The #GtkSourceCompletionContext
  * with which to start the completion.
@@ -2839,7 +2876,7 @@ gtk_source_completion_new (GtkSourceView *view)
  * gtk_source_completion_add_provider:
  * @completion: a #GtkSourceCompletion.
  * @provider: a #GtkSourceCompletionProvider.
- * @error: (allow-none): a #GError.
+ * @error: a #GError.
  *
  * Add a new #GtkSourceCompletionProvider to the completion object. This will
  * add a reference @provider, so make sure to unref your own copy when you
@@ -2884,7 +2921,7 @@ gtk_source_completion_add_provider (GtkSourceCompletion          *completion,
  * gtk_source_completion_remove_provider:
  * @completion: a #GtkSourceCompletion.
  * @provider: a #GtkSourceCompletionProvider.
- * @error: (allow-none): a #GError.
+ * @error: a #GError.
  *
  * Remove @provider from the completion.
  *
@@ -2916,7 +2953,7 @@ gtk_source_completion_remove_provider (GtkSourceCompletion          *completion,
 		return FALSE;
 	}
 
-	completion->priv->providers = g_list_remove_link (completion->priv->providers, item);
+	completion->priv->providers = g_list_delete_link (completion->priv->providers, item);
 
 	g_object_unref (provider);
 
@@ -2972,8 +3009,8 @@ gtk_source_completion_get_info_window (GtkSourceCompletion *completion)
  * The #GtkSourceView associated with @completion, or %NULL if the view has been
  * destroyed.
  *
- * Returns: (type GtkSource.View) (nullable) (transfer none):
- * The #GtkSourceView associated with @completion, or %NULL.
+ * Returns: (nullable) (transfer none): The #GtkSourceView associated with
+ * @completion, or %NULL.
  */
 GtkSourceView *
 gtk_source_completion_get_view (GtkSourceCompletion *completion)
@@ -2986,7 +3023,7 @@ gtk_source_completion_get_view (GtkSourceCompletion *completion)
 /**
  * gtk_source_completion_create_context:
  * @completion: a #GtkSourceCompletion.
- * @position: (allow-none): a #GtkTextIter, or %NULL.
+ * @position: (nullable): a #GtkTextIter, or %NULL.
  *
  * Create a new #GtkSourceCompletionContext for @completion. The position where
  * the completion occurs can be specified by @position. If @position is %NULL,
