@@ -19,14 +19,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifndef GTK_SOURCE_GUTTER_RENDERER_PRIVATE_H
+#define GTK_SOURCE_GUTTER_RENDERER_PRIVATE_H
 
-#ifndef __GTK_SOURCE_GUTTER_RENDERER_PRIVATE_H__
-#define __GTK_SOURCE_GUTTER_RENDERER_PRIVATE_H__
-
-#include <glib-object.h>
 #include <gtk/gtk.h>
-#include <gdk/gdk.h>
-#include <gtksourceview/gtksourcegutterrenderer.h>
+#include "gtksourcetypes.h"
 
 G_BEGIN_DECLS
 
@@ -35,11 +32,6 @@ void _gtk_source_gutter_renderer_set_view         (GtkSourceGutterRenderer *rend
                                                    GtkTextView             *view,
                                                    GtkTextWindowType        window_type);
 
-G_GNUC_INTERNAL
-void _gtk_source_gutter_renderer_unset_view       (GtkSourceGutterRenderer *renderer);
-
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_GUTTER_RENDERER_PRIVATE_H__ */
-
-/* vi:ts=8 */
+#endif /* GTK_SOURCE_GUTTER_RENDERER_PRIVATE_H */
