@@ -91,7 +91,7 @@ static GTimer *pagination_timer = NULL;
 /* Number of pages paginated on each invocation of the paginate() method. */
 #define PAGINATION_CHUNK_SIZE 3
 
-typedef enum
+typedef enum _PaginatorState
 {
 	/* Initial state: properties can be changed only when the paginator
 	   is in the INIT state */
@@ -445,7 +445,9 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							      "Source Buffer",
 							      "The GtkSourceBuffer object to print",
 							      GTK_SOURCE_TYPE_BUFFER,
-							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+							      G_PARAM_READWRITE |
+							      G_PARAM_CONSTRUCT_ONLY |
+							      G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourcePrintCompositor:tab-width:
@@ -465,7 +467,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							    1,
 							    MAX_TAB_WIDTH,
 							    DEFAULT_TAB_WIDTH,
-							    G_PARAM_READWRITE));
+							    G_PARAM_READWRITE |
+							    G_PARAM_STATIC_STRINGS));
 
 
 	/**
@@ -485,7 +488,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							    "",
 							    GTK_TYPE_WRAP_MODE,
 							    GTK_WRAP_NONE,
-							    G_PARAM_READWRITE));
+							    G_PARAM_READWRITE |
+							    G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourcePrintCompositor:highlight-syntax:
@@ -503,7 +507,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							       "Highlight Syntax",
 							       "",
 							       TRUE,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE |
+							       G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourcePrintCompositor:print-line-numbers:
@@ -523,7 +528,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							    "Print Line Numbers",
 							    "",
 							    0, 100, 1,
-							    G_PARAM_READWRITE));
+							    G_PARAM_READWRITE |
+							    G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourcePrintCompositor:print-header:
@@ -545,7 +551,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							       "Print Header",
 							       "",
 							       FALSE,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE |
+							       G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourcePrintCompositor:print-footer:
@@ -567,7 +574,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							       "Print Footer",
 							       "",
 							       FALSE,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE |
+							       G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourcePrintCompositor:body-font-name:
@@ -589,7 +597,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							      "Body Font Name",
 							      "",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE |
+							      G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourcePrintCompositor:line-numbers-font-name:
@@ -612,7 +621,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							      "Line Numbers Font Name",
 							      "",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE |
+							      G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourcePrintCompositor:header-font-name:
@@ -635,7 +645,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							      "Header Font Name",
 							      "",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE |
+							      G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourcePrintCompositor:footer-font-name:
@@ -658,7 +669,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							      "Footer Font Name",
 							      "",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE |
+							      G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GtkSourcePrintCompositor:n-pages:
@@ -674,7 +686,8 @@ gtk_source_print_compositor_class_init (GtkSourcePrintCompositorClass *klass)
 							   "Number of pages",
 							   "",
 							   -1, G_MAXINT, -1,
-							   G_PARAM_READABLE));
+							   G_PARAM_READABLE |
+							   G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -1117,9 +1130,9 @@ gtk_source_print_compositor_get_print_footer (GtkSourcePrintCompositor *composit
  * gtk_source_print_compositor_set_header_format:
  * @compositor: a #GtkSourcePrintCompositor.
  * @separator: %TRUE if you want a separator line to be printed.
- * @left: (allow-none): a format string to print on the left of the header.
- * @center: (allow-none): a format string to print on the center of the header.
- * @right: (allow-none): a format string to print on the right of the header.
+ * @left: (nullable): a format string to print on the left of the header.
+ * @center: (nullable): a format string to print on the center of the header.
+ * @right: (nullable): a format string to print on the right of the header.
  *
  * Sets strftime like header format strings, to be printed on the
  * left, center and right of the top of each page.  The strings may
@@ -1171,9 +1184,9 @@ gtk_source_print_compositor_set_header_format (GtkSourcePrintCompositor *composi
  * gtk_source_print_compositor_set_footer_format:
  * @compositor: a #GtkSourcePrintCompositor.
  * @separator: %TRUE if you want a separator line to be printed.
- * @left: (allow-none): a format string to print on the left of the footer.
- * @center: (allow-none): a format string to print on the center of the footer.
- * @right: (allow-none): a format string to print on the right of the footer.
+ * @left: (nullable): a format string to print on the left of the footer.
+ * @center: (nullable): a format string to print on the center of the footer.
+ * @right: (nullable): a format string to print on the right of the footer.
  *
  * See gtk_source_print_compositor_set_header_format() for more information
  * about the parameters.
@@ -1309,7 +1322,7 @@ gtk_source_print_compositor_get_body_font_name (GtkSourcePrintCompositor *compos
 /**
  * gtk_source_print_compositor_set_line_numbers_font_name:
  * @compositor: a #GtkSourcePrintCompositor.
- * @font_name: (allow-none): the name of the font for line numbers, or %NULL.
+ * @font_name: (nullable): the name of the font for line numbers, or %NULL.
  *
  * Sets the font for printing line numbers on the left margin.  If
  * %NULL is supplied, the default font (i.e. the one being used for the
@@ -1370,7 +1383,7 @@ gtk_source_print_compositor_get_line_numbers_font_name (GtkSourcePrintCompositor
 /**
  * gtk_source_print_compositor_set_header_font_name:
  * @compositor: a #GtkSourcePrintCompositor.
- * @font_name: (allow-none): the name of the font for header text, or %NULL.
+ * @font_name: (nullable): the name of the font for header text, or %NULL.
  *
  * Sets the font for printing the page header. If
  * %NULL is supplied, the default font (i.e. the one being used for the
@@ -1432,7 +1445,7 @@ gtk_source_print_compositor_get_header_font_name (GtkSourcePrintCompositor *comp
 /**
  * gtk_source_print_compositor_set_footer_font_name:
  * @compositor: a #GtkSourcePrintCompositor.
- * @font_name: (allow-none): the name of the font for the footer text, or %NULL.
+ * @font_name: (nullable): the name of the font for the footer text, or %NULL.
  *
  * Sets the font for printing the page footer. If
  * %NULL is supplied, the default font (i.e. the one being used for the
